imgly_editor library

Classes

EditorResult
An editor result is returned from a successful editor export and contains the relevant export information.
EditorSettings
The EditorSettings are used to provide the information needed by the editor to operate.
IMGLYEditor
A source for the editor.

Enums

EditorPreset
An editor preset for an existing UI configuration.

Extensions

EditorPresetStringValue on EditorPreset
An extension to make the string value accessible.