MethodChannelIMGLYEditor class

An implementation of IMGLYEditorPlatform that uses method channels.

Inheritance

Constructors

MethodChannelIMGLYEditor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openEditor({Source? source, EditorPreset? preset = EditorPreset.design, required EditorSettings settings, Map<String, dynamic>? metadata}) → Future<EditorResult?>
Opens the creative editor.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited