IMGLYEditorPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • IMGLYEditorPlatform
Implementers

Constructors

IMGLYEditorPlatform()
Constructs a ImglyEditorPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openEditor({Source? source, EditorPreset? preset = EditorPreset.design, required EditorSettings settings, Map<String, dynamic>? metadata}) → Future<EditorResult?>
Opens the creative editor.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ IMGLYEditorPlatform
The default instance of IMGLYEditorPlatform to use.
getter/setter pair