EditorResult class

An editor result is returned from a successful editor export and contains the relevant export information.

Constructors

EditorResult({String? scene, String? artifact, String? thumbnail, Map<String, dynamic> metadata = const {}})
Creates a new EditorResult from the given properties. The scene is a string representation of the exported scene which can be used to load into the editor again. The artifact represents the exported file which can be an image, a video or a document (e.g. PDF) depending on the UI. The thumbnail is a preview of the artifact. In case the scene contains multiple pages, the thumbnail always represents a preview of the first page and for videos of the first frame (if not modified natively). The metadata can be used to process any Map<String, dynamic> and is an empty map per default.
EditorResult.fromJson(Map<String, dynamic> json)
Creates a new EditorResult from the given json.
factory

Properties

artifact → String?
The uri of the exported image/video/pdf as String.
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
Metadata associated with the export. Should be customizable by the customer using the onExport interface.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scene → String?
The uri of the scene as String.
final
thumbnail → String?
The uri of the thumbnail of the artifact as String.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited