EditorSettings class

The EditorSettings are used to provide the information needed by the editor to operate.

Constructors

EditorSettings({String? license, String baseUri = "https://cdn.img.ly/packages/imgly/cesdk-flutter/1.69.0/assets", String? userId})
Creates new EditorSettings from the given properties.

Properties

baseUri String
The base URI used by the engine for built-in assets like emoji and fallback fonts, and by the editor for its default and demo asset sources (stickers, filters, and more).
final
hashCode int
The hash code for this object.
no setterinherited
license String?
The license of the editor. Pass null to run the SDK in evaluation mode with a watermark.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
Unique ID tied to your application's user. This helps us accurately calculate monthly active users (MAU).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the instance to a Map<String, dynamic> for JSON encoding.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited