baseUri property
The base URI used by the engine for built-in assets like emoji and fallback fonts, and by the editor for its default and demo asset sources (stickers, filters, and more).
By default, assets are loaded from the IMG.LY CDN at
https://cdn.img.ly/packages/imgly/cesdk-flutter/<version>/assets.
For production use, we recommend downloading the assets from
https://cdn.img.ly/packages/imgly/cesdk-flutter/<version>/imgly-assets.zip,
hosting them on your own server, and setting baseUri to your
hosted location.
Implementation
final String baseUri;